@@ -49,8 +49,9 @@ def plot_drawdown(data_df, column_name, error_message = 'no data'):
     fig.update_xaxes(rangeslider_visible=True)
     return fig
 
-def investigate_drawdown(daily_data_df, column_toinvestigate = 'close'):
-    daily_data_df['normalized_strategy'] = daily_data_df[column_toinvestigate]
+def investigate_drawdown(data_df, column_toinvestigate = 'close'):
+    data_df['normalized_strategy'] = data_df[column_toinvestigate]
+    daily_data_df = riskmetrics.filter_daily(data_df['normalized_strategy'].copy())
 
     ############# strategy drawdown
     dd_norm = riskmetrics.drawdown(daily_data_df['normalized_strategy'])
