@@ -534,7 +534,7 @@ def plot_multiple_bar_series(data_df, split =False, logy = True, title = 'Strate
             xanchor="right",
             x=1
         ))
-        fig.update_xaxes(rangeslider_visible=True)
+        fig.update_xaxes(rangeslider_visible=False)
         if put_on_same_scale:
             fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
 
@@ -558,7 +558,7 @@ def plot_multiple_bar_series(data_df, split =False, logy = True, title = 'Strate
         if logy:
             fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=1)
         fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
-        fig.update_xaxes(rangeslider_visible=True)
+        fig.update_xaxes(rangeslider_visible=False)
         fig.update_layout(height=height, width=width, showlegend=True, legend=dict(
             orientation="h",
             yanchor="bottom",
@@ -570,3 +570,23 @@ def plot_multiple_bar_series(data_df, split =False, logy = True, title = 'Strate
             fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
 
         return fig
+
+def compute_spider_diagram(categories=None, rankings=None, title=''):
+    import plotly.graph_objects as go
+    fig = go.Figure()
+    fig.add_trace(go.Scatterpolar(
+        r=rankings,
+        theta=categories,
+        fill='toself',
+        name=title
+    ))
+    fig.update_layout(
+        title=title,
+        polar=dict(
+            radialaxis=dict(
+                visible=True,
+                range=[0, 1]
+            )),
+        showlegend=False
+    )
+    return fig
\ No newline at end of file
